$FespExpansionTileBuilderData class

Constructors

$FespExpansionTileBuilderData({required List<Widget> children, required CrossAxisAlignment expandedCrossAxisAlignment, required Alignment expandedAlignment, required EdgeInsetsGeometry childrenPadding, required Widget title, required Color backgroundColor})
const

Properties

backgroundColor Color
final
children List<Widget>
final
childrenPadding EdgeInsetsGeometry
final
expandedAlignment Alignment
final
expandedCrossAxisAlignment CrossAxisAlignment
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title Widget
final

Methods

copyWith({List<Widget>? children, CrossAxisAlignment? expandedCrossAxisAlignment, Alignment? expandedAlignment, EdgeInsetsGeometry? childrenPadding, Widget? title, Color? backgroundColor}) $FespExpansionTileBuilderData
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited