$FespMenuItemButtonData class

Constructors

$FespMenuItemButtonData({required Widget child, required void onPressed()})
const

Properties

child Widget
final
hashCode int
The hash code for this object.
no setterinherited
onPressed → void Function()
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Widget? child, void onPressed()?}) $FespMenuItemButtonData
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited