$FespMenuAnchorBuilderData class
Constructors
- $FespMenuAnchorBuilderData({required Widget builder(BuildContext, MenuController, Widget?), })
-
const
Properties
- builder → Widget Function(BuildContext, MenuController, Widget?)
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{Widget builder(BuildContext, MenuController, Widget?)?, }) → $FespMenuAnchorBuilderData -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited