FespPopupMenuData class
- Annotations
-
- @FespNodeBuildersA.new(builders: [FespNodeBuilderField(className: 'FespMenuAnchorBuilderData', returnType: 'MenuAnchor', classFields: [FespNodeBuilderClassField(type: 'Widget Function(BuildContext, MenuController, Widget?)', name: 'builder'), FespNodeBuilderClassField(type: 'List<Widget>', name: 'menuChildren')]), FespNodeBuilderField(className: 'FespMenuItemButtonData', returnType: 'MenuItemButton', classFields: [FespNodeBuilderClassField(type: 'Widget', name: 'child'), FespNodeBuilderClassField(type: 'void Function()', name: 'onPressed')])])
Constructors
-
FespPopupMenuData({required Map<
Object, Widget> items, required dynamic onChange(Object value), MenuAnchor fespBuilder0(BuildContext p0, $FespMenuAnchorBuilderData p1)?, MenuItemButton fespBuilder1(BuildContext p0, $FespMenuItemButtonData p1)?}) -
const
Properties
- fespBuilder0 → MenuAnchor Function(BuildContext p0, $FespMenuAnchorBuilderData p1)?
-
finalinherited
- fespBuilder1 → MenuItemButton Function(BuildContext p0, $FespMenuItemButtonData p1)?
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
items
→ Map<
Object, Widget> -
final
- onChange → dynamic Function(Object value)
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited