$FespSliderBuilderData class
Constructors
Properties
- divisions → int?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- label → String
-
final
- max → double
-
final
- min → double
-
final
- onChanged → dynamic Function(double value)?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → double
-
final
Methods
-
copyWith(
{int? divisions, double? min, double? max, double? value, String? label, dynamic onChanged(double value)?}) → $FespSliderBuilderData -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited